! gtool.f90 - gtool4 module
! Copyright (C) by TOYODA Eizi, 2000.  All rights reserved.
! vi: set sw=4 ts=8:

module gtool 

    use gtool_frame
    implicit none

contains

    type(VARYING_STRING) function GtoolArgument(n, default) result(result)
	integer, intent(in):: n
	character(len = *), intent(in), optional:: default
	character(len = 128):: buffer
    continue
	call DclGetArgument(n, buffer)
	result = trim(buffer)
	if (present(default) .and. buffer == '') result = default
    end function

end module
